""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""
" NeoVim Config
""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""

" Package Management {{{
if &compatible
  set nocompatible
endif

set runtimepath+=$HOME/.config/nvim/bundle/dein.vim

call dein#begin('$HOME/.config/nvim/bundle/dein.vim')

" Management
call dein#add('Shougo/dein.vim')
call dein#add('tbknl/vimproject')

" Completion
call dein#add('Shougo/deoplete.nvim', { 'do': ':UpdateRemotePlugins' })

" VimLang
call dein#add('Shougo/neco-vim', {'on_ft': 'vim'})
call dein#add('ujihisa/neco-look')

" Python
call dein#add('zchee/deoplete-jedi')

" Go
call dein#add('zchee/deoplete-go', {'build': 'make'},{'on_ft': 'go'})

" CPP
call dein#add('zchee/deoplete-clang', {'on_ft': 'cpp'})

call dein#add('vdeurzen/ale')

" UI
call dein#add('morhetz/gruvbox')
call dein#add('ervandew/supertab')
call dein#add('mhartington/oceanic-next')
call dein#add('mkarmona/colorsbox')
call dein#add('vim-airline/vim-airline')
call dein#add('ntpeters/vim-better-whitespace')
call dein#add('ryanoasis/vim-devicons')
call dein#add('Yggdroot/indentLine')
call dein#add('haya14busa/incsearch.vim')

" Language Support
call dein#add('fatih/vim-go', {'on_ft': 'go'})

call dein#add('octol/vim-cpp-enhanced-highlight')

" Utilities
call dein#add('majutsushi/tagbar')
call dein#add('tpope/vim-fugitive')
call dein#add('Raimondi/delimitMate')
call dein#add('tpope/vim-commentary')
call dein#add('scrooloose/nerdtree')
call dein#add('Xuyuanp/nerdtree-git-plugin')
call dein#add('Chiel92/vim-autoformat')
call dein#add('Shougo/unite.vim')
call dein#add('Shougo/Denite.nvim')
call dein#add('Shougo/vimproc.vim', {'build' : 'make'})

call dein#end()

if dein#check_install()
    call dein#install()
endif

filetype plugin indent on

" }}}

" General {{{

set fileformats=unix,mac,dos
set modeline
set modelines=5

set whichwrap+=<,>,h,l
set mouse=a

" When joining lines, join the spaces too
set joinspaces

" Search options
set incsearch
set hlsearch
set ignorecase
set smartcase

let g:python_host_prog="/usr/bin/python2"

let g:python3_host_prog="/usr/bin/python3"

" }}}

" History {{{

set history=1000
set undofile
set undodir=$HOME/.config/nvim/undo
set undolevels=1000

" }}}

" Formatting {{{

set comments=s1:/*,mb:*,ex:*/,://,b:#,:%,s1:{-,mb:-,ex:-},:--
set formatoptions=qroctn

" }}}

" Indentation {{{

set shiftwidth=4
set tabstop=4
set shiftround
set expandtab
set autoindent
set copyindent
set smarttab
set softtabstop=4

" }}}

" Folding {{{

autocmd InsertEnter * if !exists('w:last_fdm') | let w:last_fdm=&foldmethod | setlocal foldmethod=manual | endif
autocmd InsertLeave,WinLeave * if exists('w:last_fdm') | let &l:foldmethod=w:last_fdm | unlet w:last_fdm | endif

set foldmethod=syntax
set foldlevel=0

" }}}

" Includes {{{

source $HOME/.config/nvim/keyboard.vimrc
source $HOME/.config/nvim/ui.vimrc
source $HOME/.config/nvim/plugin-config.vimrc
source $HOME/.config/nvim/autogroups.vimrc
source $HOME/.config/nvim/unite-git.vimrc

" }}}
